Labels

Struct Labels 

pub struct Labels { /* private fields */ }
Labels definition

Implementations

Source

impl Labels

Labels implementation

pub fn new() -> Labels

Creates a Labels instance.

pub fn with_url(url: &str) -> Labels

Creates a Labels instance.

Arguments
  • url - API url
pub fn with_url_token(url: &str, token: &str) -> Labels

Creates a Labels instance.

Arguments
  • url - API url
  • token - API token
pub async fn label(&self, text: &str, labels: &Vec<&str>) -> IndexResults

Applies a zero shot classifier to text using a list of labels. Returns a list of {id: value, score: value} sorted by highest score, where id is the index in labels.

Arguments
  • text - input text
  • labels - list of labels
pub async fn batchlabel( &self, texts: &Vec<&str>, labels: &Vec<&str>, ) -> IndexResultsBatch

Applies a zero shot classifier to list of text using a list of labels. Returns a list of {id: value, score: value} sorted by highest score, where id is the index in labels per text element.

Arguments
  • texts - list of texts
  • labels - list of labels